Skip to contents

TBA rankings can be calculated from partial information, for example before all of the qualifying matches are played or scores are posted.

Usage

calculate_tba_ranking(data)

Arguments

data

tibble of match information - it is assumed that each line corresponds to the score breakdown of one team in one event's match.

Examples

# example code
if (FALSE) { # \dontrun{
# get all matches for one event:
clash_matches <- get_records("event/2025cttd/matches")
# get the score breakdown for each of the teams in each match
clash_details <- get_match_details(clash_matches)
# now get the rankings:
calculate_tba_ranking(clash_details)
} # }