Skip to contents

Get team rankings for an event

Usage

tba_ranking(event_code)

Arguments

event_code

character string for an event - usually an eight-character string consisting of a four-digit year followed by an acronym for the event, such as 'cttd' for "Cow Town Throw Down".

Value

tibble of the rankings for all teams that participated in the event

Examples

tba_ranking("2024cttd") # same team ranking as in example for `calc_ranking_tba_2024`
#> # A tibble: 42 × 11
#>    team_key  rank `Ranking Score` `Avg Coop` `Avg Match` `Avg Auto` `Avg Stage`
#>    <chr>    <int>           <dbl>      <dbl>       <dbl>      <dbl>       <dbl>
#>  1 frc3284      1            3.13       0.88        56.2       21.5        4.38
#>  2 frc3928      2            2.63       0.75        54.4       25.1        5.38
#>  3 frc5126      3            2.5        0.88        53.1       20.2        3.5 
#>  4 frc1769      4            2.38       0.38        44.6       17.9        4.25
#>  5 frc6424      5            2.25       0.63        57.5       21.4        6.38
#>  6 frc1987      6            2          0.63        54         27.4        4.63
#>  7 frc1982      7            2          0.5         47         17.9        4.13
#>  8 frc2357      8            1.88       0.88        56.6       24.2        7   
#>  9 frc1108      9            1.88       0.63        58.2       24          5.38
#> 10 frc5013     10            1.88       0.38        50.1       17.8        3.88
#> # ℹ 32 more rows
#> # ℹ 4 more variables: dq <int>, matches_played <int>, qual_average <lgl>,
#> #   record <df[,3]>