Calculate the TBA rankings from qualifying match scores for the current season
Source:R/calculate_tba_ranking.R
calculate_tba_ranking.RdTBA rankings can be calculated from partial information, for example before all of the qualifying matches are played or scores are posted.
Examples
# example code
if (FALSE) { # \dontrun{
# get all matches for one event:
clash_matches <- get_records("event/2025cttd/matches")
# get the score breakdown for each of the teams in each match
clash_details <- get_match_details(clash_matches)
# now get the rankings:
calculate_tba_ranking(clash_details)
} # }