get_api_key checks whether the key for the API to The Blue Aliance (TBA) is available
in the system environment. The function will warn the user in case the key is not found and
will provide instructions on how to set the key.
In order to access the API, the user will have to sign up for a (free) account with https://www.thebluealliance.com/account.
The functions in this package expect access to TBA's read APIv3. Once created,
call the function set_api_key with the string found under X-TBA-Auth-Key.
set_api_key makes the specified key available as a variable in the system environment for the current session.