Reformat match information into an approximate wide form
Source:R/get_match_details.R
get_match_details.RdThe records from TBA come in the form of one line for each match, where the
two alliances and their corresponding score breakdowns are in list variables.
The get_match_details function returns the score breakdown for each team and each match in the
competition, i.e. the new dataset will have about 6 times the number of rows of the original.
HH: still need to test: what happens, when there is a surrogate team used in a match?
Examples
clash_matches <- get_records("event/2024iawes/matches")
clash_details <- get_match_details(clash_matches)